@@ -25,7 +25,7 @@ class MarkdownElement:
         """Factory to create markdown element,
 
         Args:
-            markdown (Markdown): THe parent Markdown object.
+            markdown (Markdown): The parent Markdown object.
             node (Any): A node from Pygments.
 
         Returns:
@@ -177,7 +177,7 @@ class CodeBlock(TextElement):
     ) -> RenderResult:
         code = str(self.text).rstrip()
         syntax = Panel(
-            Syntax(code, self.lexer_name, theme=self.theme),
+            Syntax(code, self.lexer_name, theme=self.theme, word_wrap=True),
             border_style="dim",
             box=box.SQUARE,
         )
@@ -312,7 +312,7 @@ class ImageItem(TextElement):
         """Factory to create markdown element,
 
         Args:
-            markdown (Markdown): THe parent Markdown object.
+            markdown (Markdown): The parent Markdown object.
             node (Any): A node from Pygments.
 
         Returns:
@@ -399,7 +399,7 @@ class Markdown(JupyterMixin):
         style (Union[str, Style], optional): Optional style to apply to markdown.
         hyperlinks (bool, optional): Enable hyperlinks. Defaults to ``True``.
         inline_code_lexer: (str, optional): Lexer to use if inline code highlighting is
-            enabled. Defaults to "python".
+            enabled. Defaults to None.
         inline_code_theme: (Optional[str], optional): Pygments theme for inline code
             highlighting, or None for no highlighting. Defaults to None.
     """
@@ -441,6 +441,7 @@ class Markdown(JupyterMixin):
     ) -> RenderResult:
         """Render markdown to the console."""
         style = console.get_style(self.style, default="none")
+        options = options.update(height=None)
         context = MarkdownContext(
             console,
             options,
@@ -612,11 +613,12 @@ if __name__ == "__main__":  # pragma: no cover
         import pydoc
         import io
 
+        fileio = io.StringIO()
         console = Console(
-            file=io.StringIO(), force_terminal=args.force_color, width=args.width
+            file=fileio, force_terminal=args.force_color, width=args.width
         )
         console.print(markdown)
-        pydoc.pager(console.file.getvalue())  # type: ignore
+        pydoc.pager(fileio.getvalue())
 
     else:
         console = Console(force_terminal=args.force_color, width=args.width)
