@@ -253,6 +253,7 @@ class Text(JupyterMixin):
         emoji_variant: Optional[EmojiVariant] = None,
         justify: Optional["JustifyMethod"] = None,
         overflow: Optional["OverflowMethod"] = None,
+        end: str = "\n",
     ) -> "Text":
         """Create Text instance from markup.
 
@@ -261,6 +262,7 @@ class Text(JupyterMixin):
             emoji (bool, optional): Also render emoji code. Defaults to True.
             justify (str, optional): Justify method: "left", "center", "full", "right". Defaults to None.
             overflow (str, optional): Overflow method: "crop", "fold", "ellipsis". Defaults to None.
+            end (str, optional): Character to end text with. Defaults to "\\\\n".
 
         Returns:
             Text: A Text instance with markup rendered.
@@ -270,6 +272,7 @@ class Text(JupyterMixin):
         rendered_text = render(text, style, emoji=emoji, emoji_variant=emoji_variant)
         rendered_text.justify = justify
         rendered_text.overflow = overflow
+        rendered_text.end = end
         return rendered_text
 
     @classmethod
@@ -1078,18 +1081,21 @@ class Text(JupyterMixin):
                     break
                 start_line_no = (lower_bound + upper_bound) // 2
 
-            end_line_no = lower_bound = start_line_no
-            upper_bound = line_count
+            if span_end < line_end:
+                end_line_no = start_line_no
+            else:
+                end_line_no = lower_bound = start_line_no
+                upper_bound = line_count
 
-            while True:
-                line_start, line_end = line_ranges[end_line_no]
-                if span_end < line_start:
-                    upper_bound = end_line_no - 1
-                elif span_end > line_end:
-                    lower_bound = end_line_no + 1
-                else:
-                    break
-                end_line_no = (lower_bound + upper_bound) // 2
+                while True:
+                    line_start, line_end = line_ranges[end_line_no]
+                    if span_end < line_start:
+                        upper_bound = end_line_no - 1
+                    elif span_end > line_end:
+                        lower_bound = end_line_no + 1
+                    else:
+                        break
+                    end_line_no = (lower_bound + upper_bound) // 2
 
             for line_no in range(start_line_no, end_line_no + 1):
                 line_start, line_end = line_ranges[line_no]
